@@ -310,4 +310,18 @@
 # define CLUTTER_AVAILABLE_IN_1_18              _CLUTTER_EXTERN
 #endif
 
+#if CLUTTER_VERSION_MIN_REQUIRED >= CLUTTER_VERSION_1_20
+# define CLUTTER_DEPRECATED_IN_1_20             CLUTTER_DEPRECATED
+# define CLUTTER_DEPRECATED_IN_1_20_FOR(f)      CLUTTER_DEPRECATED_FOR(f)
+#else
+# define CLUTTER_DEPRECATED_IN_1_20             _CLUTTER_EXTERN
+# define CLUTTER_DEPRECATED_IN_1_20_FOR(f)      _CLUTTER_EXTERN
+#endif
+
+#if CLUTTER_VERSION_MAX_ALLOWED < CLUTTER_VERSION_1_20
+# define CLUTTER_AVAILABLE_IN_1_20              CLUTTER_UNAVAILABLE(1, 20)
+#else
+# define CLUTTER_AVAILABLE_IN_1_20              _CLUTTER_EXTERN
+#endif
+
 #endif /* __CLUTTER_MACROS_H__ */
